#!/usr/bin/python3

import setuptools
import os
from pathlib import Path
import shutil

this_directory = Path(__file__).parent
desktop_entry_path = os.path.expanduser("~/.local/share/applications")
icon_path = os.path.expanduser("~/.local/share/icons/hicolor/scalable/apps")

os.makedirs(icon_path, exist_ok=True)

shutil.copy(f"{this_directory}/wobuzz.desktop", f"{desktop_entry_path}/wobuzz.desktop")  # install desktop entry
shutil.copy(f"{this_directory}/wobuzz/icon.svg", f"{icon_path}/wobuzz.svg")  # install icon

# use readme file as long description
long_description = (this_directory / "README.md").read_text()

setuptools.setup(
    name="Wobuzz",
    version="0.1a2",
    description="An audio player made by The Wobbler",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://teapot.informationsanarchistik.de/Wobbl/Wobuzz",
    author="The Wobbler",
    author_email="emil@i21k.de",
    license="GNU GPLv3",
    packages=setuptools.find_packages(include=["wobuzz", "wobuzz.*"]),
    package_data={"": ["*.txt", "*.svg"]},
    install_requires=[
        "PyQt6",
        "tinytag",
        "pydub",
        "pygame",
        "wobbl_tools @ git+https://teapot.informationsanarchistik.de/Wobbl/wobbl_tools@9b7e796877781f77f6df93475750c15a0ca51dd9#egg=wobbl_tools"
    ],
    entry_points={
        "console_scripts": ["wobuzz=wobuzz.command_line:main"],
    }
)
